@@ -55,6 +55,12 @@ class ChessMove:
     # If this move can be used as a resignation
     fiftyMoveRule = False
     threeFoldRepetition = False
+    
+    # A comment about this move
+    comment = ''
+
+    # Numeric annotation glyph for move
+    nag     = ''
 
 class ChessPlayer:
     """
@@ -478,7 +484,7 @@ class ChessGame:
             colour = chess.board.WHITE
         else:
             colour = chess.board.BLACK
-        
+
         # If move is SAN process it as such
         try:
             (start, end, _, _, promotionType, _) = chess.lan.decode(colour, move)
@@ -526,6 +532,8 @@ class ChessGame:
         m.opponentCanMove     = moveResult.opponentCanMove
         m.fiftyMoveRule       = moveResult.fiftyMoveRule
         m.threeFoldRepetition = moveResult.threeFoldRepetition
+        #FIXME: m.comment             = move.comment
+        #FIXME: m.nag                 = move.nag
 
         self.__moves.append(m)
 
@@ -632,8 +640,8 @@ class ChessGame:
     def getMoves(self):
         """
         """
-        return self.__moves[:]
-    
+        return self.__moves
+
     def abort(self):
         """End the game"""
         # Inform players
@@ -686,37 +694,3 @@ class NetworkChessGame(ChessGame):
                A SAN move (string).
         """
         # Send to the server
-        
-            
-if __name__ == '__main__':
-    game = ChessGame()
-    
-    import pgn
-    
-    p = pgn.PGN('black.pgn')
-    g = p.getGame(0)
-
-    class PGNPlayer(ChessPlayer):
-        __moveNumber = 1
-        
-        __isWhite = True
-        
-        def __init__(self, isWhite):
-            self.__isWhite = isWhite
-        
-        def readyToMove(self):
-            if self.__isWhite:
-                move = g.getWhiteMove(self.__moveNumber)
-            else:
-                move = g.getBlackMove(self.__moveNumber)
-            self.__moveNumber += 1
-            self.move(move)
-            
-    white = PGNPlayer(True)
-    black = PGNPlayer(False)
-    
-    game.setWhite(white)
-    game.setBlack(black)
-    
-    game.start()
-    
