@@ -10,7 +10,7 @@ __all__ = ['Application']
 import sys
 import os
 import errno
-import gettext
+from gettext import gettext as _
 import traceback
 
 import config
@@ -60,8 +60,7 @@ class MovePlayer(game.ChessPlayer):
     def onPlayerMoved(self, player, move):
         """Called by chess.board.ChessPlayer"""
         self.__game.needsSaving = True
-        self.__game.view.controller.addMove(move)
-        
+
         # Update clocks
         if player is self.__game.getWhite():
             if self.__game.wT is not None:
@@ -78,6 +77,8 @@ class MovePlayer(game.ChessPlayer):
         if self.__game.view.moveNumber != -1:
             player.endMove()
             
+        self.__game.view.controller.addMove(move)
+
     def onGameEnded(self, game):
         """Called by chess.board.ChessPlayer"""
         self.__game.view.controller.endGame(game)
@@ -341,11 +342,24 @@ class Splashscreen(ui.ViewFeedback):
         self.application = application
         self.cairoScene = scene.cairo.Scene(self)
         self.scene = scene.opengl.Scene(self)
-        
+
+    def updateRotation(self, animate = True):
+        boardView = config.get('board_view')
+        if boardView == 'black':
+            rotation = 180.0
+        else:
+            rotation = 0.0
+        self.cairoScene.controller.setBoardRotation(rotation, animate)
+        self.scene.controller.setBoardRotation(rotation, animate)
+
     def onRedraw(self):
-        """
-        """
-        # FIXME: Need for scene.cairo.Scene
+        """Called by scene.SceneFeedback"""
+        self.controller.render()
+        
+    def showBoardNumbering(self, showNumbering):
+        """Called by ui.ViewFeedback"""
+        self.scene.showBoardNumbering(showNumbering)
+        self.cairoScene.showBoardNumbering(showNumbering)
 
     def renderGL(self):
         """Called by ui.ViewFeedback"""
@@ -390,12 +404,11 @@ class View(ui.ViewFeedback):
         # This should be cleaned up
         self.scene = SceneCairo(game)
         config.watch('board_view', self.__onBoardViewChanged)
-        self.updateRotation()
 
     def __onBoardViewChanged(self, key, value):
         self.updateRotation()
 
-    def updateRotation(self):
+    def updateRotation(self, animate = True):
         """
         """
         # Get the angle to face
@@ -415,7 +428,7 @@ class View(ui.ViewFeedback):
             if not isinstance(player, HumanPlayer):
                 return
 
-        self.scene.controller.setBoardRotation(rotation)
+        self.scene.controller.setBoardRotation(rotation, animate)
 
     def pieceMoved(self):
         """
@@ -426,9 +439,13 @@ class View(ui.ViewFeedback):
         self.game.getCurrentPlayer().endMove()
 
     def showMoveHints(self, showHints):
-        """Called by ui.UIFeedback"""
+        """Called by ui.ViewFeedback"""
         self.scene.showMoveHints(showHints)
-    
+
+    def showBoardNumbering(self, showNumbering):
+        """Called by ui.ViewFeedback"""
+        self.scene.controller.showBoardNumbering(showNumbering)
+
     def updateScene(self, sceneClass):
         """
         """
@@ -438,7 +455,8 @@ class View(ui.ViewFeedback):
         self.scene = sceneClass(self.game)
         self.reshape(self.width, self.height)
         self.setMoveNumber(self.moveNumber)
-        
+        self.updateRotation(animate = False)
+
     def renderGL(self):
         """Called by ui.ViewFeedback"""
         self.updateScene(SceneOpenGL)
@@ -599,8 +617,10 @@ class ChessGame(game.ChessGame):
 
         self.view = View(self)
         self.view.controller = application.ui.controller.addView(name, self.view)
-        
+        self.view.updateRotation(animate = False)
+
         self.view.showMoveHints(config.get('show_move_hints') is True)
+        self.view.showBoardNumbering(config.get('show_numbering') is True)
         
         # Watch for piece moves with a player
         self.__movePlayer = MovePlayer(self)
@@ -615,12 +635,12 @@ class ChessGame(game.ChessGame):
         
         Returns an AI player to use (game.ChessPlayer).
         """
-        description = "'" + name + "' in '" + self.name + "'"
+        description = _("'%(name)s' in '%(game)s'") % {'name': name, 'game': self.name}
         player = AIPlayer(self.application, name, profile, level, description)
         self.__aiPlayers.append(player)
         self.application.watchAIPlayer(player)
         return player
-    
+
     def addHumanPlayer(self, name):
         """Create a human player.
         
@@ -630,7 +650,7 @@ class ChessGame(game.ChessGame):
         """
         player = HumanPlayer(self, name)
         return player
-    
+
     def setTimer(self, duration, whiteTime, blackTime):
         self.duration = duration
         if duration <= 0:
@@ -735,13 +755,12 @@ class ChessGame(game.ChessGame):
             pgnGame.setTag('BlackLevel', level)
 
         moves = self.getMoves()
-        while len(moves) > 0:
-            if len(moves) == 1:
-                pgnGame.addMove(moves[0].sanMove, None)
-                break
-            else:
-                pgnGame.addMove(moves[0].sanMove, moves[1].sanMove)
-                moves = moves[2:]
+        for m in moves:
+            pgnMove = chess.pgn.PGNMove()
+            pgnMove.move = m.sanMove
+            pgnMove.nag = m.nag
+            pgnMove.comment = m.comment
+            pgnGame.addMove(pgnMove)
 
     def animate(self, timeStep):
         """
@@ -938,7 +957,7 @@ class UI(ui.UIFeedback):
         self.application = application
         
         self.splashscreen = Splashscreen(self)
-        self.controller.setDefaultView(self.splashscreen)
+        self.splashscreen.controller = self.controller.setDefaultView(self.splashscreen)
 
     def onAnimate(self, timeStep):
         """Called by ui.UIFeedback"""
@@ -951,7 +970,10 @@ class UI(ui.UIFeedback):
         except KeyError:
             return False
         else:
-            return handler.read()
+            result = handler.read()
+            if result is False:
+                self.application.ioHandlers.pop(fd)
+            return result
 
     def onGameStart(self, game):
         """Called by ui.UIFeedback"""
@@ -976,6 +998,8 @@ class UI(ui.UIFeedback):
             p = chess.pgn.PGN(path, 1)
         except chess.pgn.Error, e:
             return e.description
+        except IOError, e:
+            return e.strerror
         
         # Use the first game
         self.application.addPGNGame(p[0], path, configure)
@@ -1019,13 +1043,7 @@ class Application:
         self.__games = []
         self.ioHandlers = {}
         self.networkConnections = {}
-
-        try:
-            os.mkdir(DATA_DIR)
-        except OSError:
-            pass
-        assert(os.path.isdir(DATA_DIR))
-        
+       
         self.__detector = None#GameDetector(self)
 
         self.ui = UI(self)
@@ -1061,7 +1079,9 @@ class Application:
     def unwatchAIPlayer(self, player):
         """
         """
-        self.ioHandlers.pop(player.fileno())
+        fd = player.fileno()
+        if fd is not None:
+            self.ioHandlers.pop(fd)
 
     def addGame(self, name, whiteName, whiteType, blackName, blackType):
         """Add a chess game into glChess.
@@ -1111,8 +1131,11 @@ class Application:
         gameProperties.name = pgnGame.getTag(pgnGame.PGN_TAG_EVENT)
         gameProperties.white.name = pgnGame.getTag(pgnGame.PGN_TAG_WHITE)
         gameProperties.black.name = pgnGame.getTag(pgnGame.PGN_TAG_BLACK)
-        gameProperties.moves = pgnGame.getMoves()
-        
+        moves = []
+        for pgnMove in pgnGame.getMoves():
+            moves.append(pgnMove.move)
+        gameProperties.moves = moves            
+
         missingEngines = False
         gameProperties.white.type = pgnGame.getTag('WhiteAI', '')
         if gameProperties.white.type == '':
@@ -1147,6 +1170,14 @@ class Application:
             newGame.start(gameProperties.moves)
         else:
             newGame.start()
+            
+        # Comment on each move
+        # FIXME: This should be done through a method so the UI can update better
+        moves = newGame.getMoves()
+        pgnMoves = pgnGame.getMoves()
+        for i in xrange(len(moves)):
+            moves[i].comment = pgnMoves[i].comment
+            moves[i].nag = pgnMoves[i].nag
 
         # Get the last player to resign if the file specifies it
         result = pgnGame.getTag(pgnGame.PGN_TAG_RESULT, None)
@@ -1221,7 +1252,9 @@ class Application:
                 p = chess.pgn.PGN(path, 1)
             except chess.pgn.Error, e:
                 # TODO: Pop-up dialog
-                print 'Unable to open PGN file ' + path + ':' + str(e)
+                print 'Unable to open PGN file %s: %s' % (path, str(e))
+            except IOError, e:
+                print 'Unable to open PGN file %s: %s' % (path, str(e))
             else:
                 # Use the first game
                 if len(p) > 0:
@@ -1232,8 +1265,8 @@ class Application:
         try:
             self.ui.controller.run()
         except:
-            print 'glChess has crashed. Please report this bug to http://glchess.sourceforge.net'
-            print 'Debug output:'
+            print _('glChess has crashed. Please report this bug to http://bugzilla.gnome.org')
+            print _('Debug output:')
             print traceback.format_exc()
             self.quit()
             sys.exit(1)
@@ -1303,7 +1336,7 @@ class Application:
             return
         
         fname = AUTOSAVE_FILE
-        print 'Auto-saving to ' + fname + '...'
+        print 'Auto-saving to %s...' % fname
         
         try:
             f = file(fname, 'a')
