@@ -30,6 +30,7 @@
 
 #include <games-gridframe.h>
 #include <games-stock.h>
+#include <games-sound.h>
 
 #include "connect4.h"
 #include "main.h"
@@ -491,34 +492,29 @@ game_free (void)
 static void
 play_sound (SoundID id)
 {
-  if (!p.do_sound)
-    return;
+ /* if (!p.do_sound)
+    return;*/
 
-  /* This has been disabled until we get appropriate sounds. */
-  /* Fixing this should also involve moving away from the 
-   * gnome_triggers API. */
-#if 0
   switch (id) {
   case SOUND_DROP:
-    gnome_triggers_do (NULL, NULL, APPNAME, "drop", NULL);
+    games_sound_play ("slide");
     break;
   case SOUND_I_WIN:
-    gnome_triggers_do (NULL, NULL, APPNAME, "iwin", NULL);
+    games_sound_play ("reverse");
     break;
   case SOUND_YOU_WIN:
-    gnome_triggers_do (NULL, NULL, APPNAME, "youwin", NULL);
+    games_sound_play ("bonus");
     break;
   case SOUND_PLAYER_WIN:
-    gnome_triggers_do (NULL, NULL, APPNAME, "playerwin", NULL);
+    games_sound_play ("bonus");
     break;
   case SOUND_DRAWN_GAME:
-    gnome_triggers_do (NULL, NULL, APPNAME, "draw", NULL);
+    games_sound_play ("reverse");
     break;
   case SOUND_COLUMN_FULL:
-    gnome_triggers_do (NULL, NULL, APPNAME, "cantmove", NULL);
+    games_sound_play ("bad");
     break;
   }
-#endif
 }
 
 
@@ -832,7 +828,7 @@ on_game_scores (GtkMenuItem * m, gpointer data)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (scorebox)->vbox), vbox, TRUE, TRUE,
 		      0);
 
-  icon = gtk_image_new_from_icon_name ("gnome-four-in-a-row", 48);
+  icon = gtk_image_new_from_icon_name ("gnome-gnect", 48);
   gtk_box_pack_start (GTK_BOX (vbox), icon, FALSE, FALSE, 0);
 
   table = gtk_table_new (3, 2, FALSE);
@@ -921,9 +917,9 @@ on_help_about (GtkAction * action, gpointer data)
 			 ("\"Four in a Row\" for GNOME, with a computer player driven by Giuliano Bertoletti's Velena Engine."),
 			 "authors", authors, "documenters", documenters,
 			 "artists", artists, "translator_credits",
-			 _("translator-credits"), "logo-icon-name",
-			 "gnome-four-in-a-row", "website",
-			 "http://www.gnome.org/projects/gnome-games/",
+			 _("translator-credits"),
+			 "logo-icon-name", "gnome-gnect",
+			 "website", "http://www.gnome.org/projects/gnome-games/",
 			 "wrap-license", TRUE, NULL);
   g_free (license);
 }
@@ -1437,7 +1433,7 @@ create_app (void)
   g_signal_connect (G_OBJECT (app), "configure_event",
 		    G_CALLBACK (on_window_resize), NULL);
 
-  gtk_window_set_default_icon_name ("gnome-four-in-a-row");
+  gtk_window_set_default_icon_name ("gnome-gnect");
 
   statusbar = gtk_statusbar_new ();
   ui_manager = gtk_ui_manager_new ();
@@ -1516,16 +1512,23 @@ int
 main (int argc, char *argv[])
 {
   GnomeProgram *program;
+  GOptionContext *context;
 
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+  g_thread_init (NULL);
+  context = g_option_context_new (NULL);
+  g_option_context_add_group (context, games_sound_get_option_group ());
+
   program = gnome_program_init (APPNAME, VERSION, LIBGNOMEUI_MODULE,
-				argc, argv, GNOME_PARAM_APP_DATADIR, DATADIR,
+				argc, argv,
+                                GNOME_PARAM_GOPTION_CONTEXT, context,
+                                GNOME_PARAM_APP_DATADIR, DATADIR,
 				NULL);
 
-  prefs_init (argc, argv);
+  prefs_init ();
   game_init ();
 
   /* init gfx */
