@@ -1,10 +1,10 @@
 import os, os.path
+import errno
 import gettext
 
 APP_DATA_DIR = os.path.join('/usr/local', 'share') 
-ICON_DIR =     os.path.join(APP_DATA_DIR,'pixmaps')
-IMAGE_DIR = os.path.join(ICON_DIR,'gnome-sudoku')
-LOCALEDIR 	= os.path.join(APP_DATA_DIR, 'locale')
+IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
+LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
 GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
 BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
 
@@ -16,7 +16,7 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.19.2"
+VERSION = "2.19.3"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2007, Thomas M. Hinkle'
@@ -42,5 +42,8 @@ _("You should have received a copy of the GNU General Public License "
 DATA_DIR = os.path.expanduser('~/.gnome2/gnome-sudoku/')
 
 def initialize_games_dir ():
-    if not os.path.exists(DATA_DIR): os.makedirs(DATA_DIR)
-
+    try:
+        os.makedirs(DATA_DIR)
+    except OSError, e:
+        if e.errno != errno.EEXIST:
+            print _('Unable to make data directory %(dir)s: %(error)s') % {'dir': DATA_DIR, 'error': e.strerror}
