@@ -12,11 +12,11 @@
 #include <gconf/gconf-client.h>
 
 G_BEGIN_DECLS
+  gboolean games_gconf_sanity_check_string (GConfClient * client,
+					    const gchar * key);
 
-gboolean games_gconf_sanity_check_string (GConfClient *client, const gchar* key);
-
-gchar* games_gconf_get_string (GConfClient *client, const gchar* key, const gchar* def);
+gchar *games_gconf_get_string (GConfClient * client, const gchar * key,
+			       const gchar * def);
 
 G_END_DECLS
-
 #endif /* __GAMES_GCONF_H__ */
