@@ -172,14 +172,16 @@ fullscreen_callback (GtkAction * action)
     gtk_window_unfullscreen (GTK_WINDOW (window));
 }
 
-static void
+static gboolean
 window_state_callback (GtkWidget * widget, GdkEventWindowState * event)
 {
   if (!(event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN))
-    return;
+    return FALSE;
 
   set_fullscreen_actions (event->new_window_state &
 			  GDK_WINDOW_STATE_FULLSCREEN);
+    
+  return FALSE;
 }
 
 /* At the end of the game, hint, shuffle and pause all become unavailable. */
@@ -690,7 +692,7 @@ you_won (void)
     if (dialog) {
       gtk_window_present (GTK_WINDOW (dialog));
     } else {
-      dialog = games_scores_dialog_new (highscores, _("Mahjongg Scores"));
+      dialog = games_scores_dialog_new (GTK_WINDOW (window), highscores, _("Mahjongg Scores"));
       games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
 						    (dialog), _("Map:"));
       message =
@@ -1002,7 +1004,7 @@ scores_callback (GtkAction * action, gpointer data)
   if (dialog) {
     gtk_window_present (GTK_WINDOW (dialog));
   } else {
-    dialog = games_scores_dialog_new (highscores, _("Mahjongg Scores"));
+    dialog = games_scores_dialog_new (GTK_WINDOW (window), highscores, _("Mahjongg Scores"));
     games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
 						  (dialog), _("Map:"));
   }
